/*
    *
    * This file is a part of Libcprime.
    * Library for bookmarking, saving recent activites, managing settings for CuboCore Application Suite
	* Copyright 2019 CuboCore Group
    *

    *
    * This program is free software; you can redistribute it and/or modify
    * it under the terms of the GNU General Public License as published by
    * the Free Software Foundation; either version 3 of the License, or
    * (at your option) any later version.
    *

    *
    * This program is distributed in the hope that it will be useful,
    * but WITHOUT ANY WARRANTY; without even the implied warranty of
    * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    * GNU General Public License for more details.
    *

    *
    * You should have received a copy of the GNU General Public License
    * along with this program; if not, vsit http://www.gnu.org/licenses/.
    *
*/


#include <QLineEdit>
#include <QDebug>
#include <QFileInfo>
#include <QPalette>

#include "filepathvalidate.h"


CPrime::FilePathValidate::FilePathValidate(QLineEdit *lineEdit, QObject *parent)
    : QObject(parent)
{
    if (!lineEdit) {
        qDebug() << "Error 'nullptr': func(FilePathValidate) : LineEdit is null.";
        return;
    }

    mLineEdit = lineEdit;

    if (!mLineEdit) {
        qDebug() << "Error : Allocation problem.";
    }

    p = new QPalette(lineEdit->palette());

    connect(mLineEdit, &QLineEdit::textChanged, this, &FilePathValidate::checkPathExistence);
}

void CPrime::FilePathValidate::addForValidation(QLineEdit *lineEdit, QObject *parent)
{
    new FilePathValidate(lineEdit, parent);
}

void CPrime::FilePathValidate::checkPathExistence(const QString &str)
{
    if (str.count()) {
        QFileInfo fi(str);
        QPalette *pal = new QPalette;
        pal->setColor(QPalette::Text, Qt::red);

        if (fi.exists()) {
            mLineEdit->setPalette(*p);
        } else {
            mLineEdit->setPalette(*pal);
        }
    } else {
        mLineEdit->setPalette(*p);
        //mLineEdit->setPlaceholderText( "Enter valid path..." );
    }
}
