/*
    *
    * This file is a part of Libcprime.
    * Library for bookmarking, saving recent activites, managing settings for CuboCore Application Suite
	* Copyright 2019 CuboCore Group
    *

    *
    * This program is free software; you can redistribute it and/or modify
    * it under the terms of the GNU General Public License as published by
    * the Free Software Foundation; either version 3 of the License, or
    * (at your option) any later version.
    *

    *
    * This program is distributed in the hope that it will be useful,
    * but WITHOUT ANY WARRANTY; without even the implied warranty of
    * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    * GNU General Public License for more details.
    *

    *
    * You should have received a copy of the GNU General Public License
    * along with this program; if not, vsit http://www.gnu.org/licenses/.
    *
*/


#include <QWidget>
#include <QFrame>
#include <QLabel>
#include <QTimer>
#include <QVBoxLayout>
#include <QDateTime>
#include <QApplication>
#include <QScreen>
#include <QDir>
#include <QSettings>

#include "settingsmanage.h"
#include "stringfunc.h"
#include "themefunc.h"
#include "validityfunc.h"
#include "infofunc.h"
#include "cvariables.h"

#include "systemnotification.h"


/*
 * MessageBox function.
 */
void CPrime::InfoFunc::messageEngine(const QString &message, CPrime::MessageType messageType, QWidget *parent)
{
    QString summary = "";
    QString icon = "";
    if (messageType == MessageType::Info) {
        summary = "Info";
        icon = "dialog-information";
    } else if (messageType == MessageType::Warning) {
        summary = "Warning";
        icon = "dialog-warning";
    } else {
        summary = "Tips";
        icon = "dialog-question";
    }

    systemNotification *notify = new systemNotification(summary, message, icon, parent);
    notify->init("CuboCore");
    notify->show();
}

QString CPrime::InfoFunc::sentDateText(const QString &dateTime)
{
    QDateTime given = QDateTime::fromString(dateTime, "dd.MM.yyyy");

    if (QDate::currentDate().toString("dd.MM.yyyy") == dateTime) {
        return QString("Today");
    } else {
        return QString(given.toString("MMMM dd"));
    }
}

bool CPrime::InfoFunc::saveToRecent(const QString &appName, const QString &pathName)
{
    settingsManage *sm = settingsManage::initialize();
    QString m_appName = /*CPrime::StringFunc::CapitalizeEachWord*/(appName);

    if (sm->value("CoreApps", "ShowRecent")) {
        if (appName.count() && pathName.count()) {
            CPrime::ValidityFunc::setupFileFolder(CPrime::FileFolderSetup::RecentActivityFile);

            QSettings recentActivity(CPrime::Variables::CC_CoreApps_RecentActFilePath(), QSettings::IniFormat);
            QDateTime currentDT =  QDateTime::currentDateTime();
            QString group = currentDT.toString("dd.MM.yyyy");
            QString key = currentDT.toString("hh.mm.ss.zzz");
            recentActivity.beginGroup(group);
            recentActivity.setValue(key, m_appName + "\t\t\t" + pathName);
            recentActivity.endGroup();
            return true;
        }
    }

    return false;
}
