/*
    *
    * This file is a part of Libcprime.
    * Library for bookmarking, saving recent activites, managing settings for CuboCore Application Suite
	* Copyright 2019 CuboCore Group
    *

    *
    * This program is free software; you can redistribute it and/or modify
    * it under the terms of the GNU General Public License as published by
    * the Free Software Foundation; either version 3 of the License, or
    * (at your option) any later version.
    *

    *
    * This program is distributed in the hope that it will be useful,
    * but WITHOUT ANY WARRANTY; without even the implied warranty of
    * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    * GNU General Public License for more details.
    *

    *
    * You should have received a copy of the GNU General Public License
    * along with this program; if not, vsit http://www.gnu.org/licenses/.
    *
*/


#include <QFileInfo>
#include <QDebug>
#include <QDir>
#include <QLineEdit>

#include "mimeutils.h"
#include "cvariables.h"
#include "filepathvalidate.h"
#include "validityfunc.h"


QString CPrime::ValidityFunc::checkIsValidDir(const QString &path)
{
    if (path.count()) {
        QFileInfo dir(path);

        if (dir.isDir()) {
            if (dir.isRoot()) {
                return path;
            } else {
                if (path.endsWith('/')) {
                    return QString(path).remove(path.length() - 1, 1);
                } else {
                    return path;
                }
            }
        }
    } else {
        return nullptr;
    }

    return nullptr;
}

QString CPrime::ValidityFunc::checkIsValidFile(const QString &file)
{
    if (file.count()) {
        QFileInfo fi(file);

        if (fi.isFile()) {
            return file;
        }
    } else {
        return nullptr;
    }

    return nullptr;
}

bool CPrime::ValidityFunc::setupFileFolder(CPrime::FileFolderSetup fs)
{
    bool status = false;

    switch (fs) {
        case CPrime::PinsFolder: {
            if (!QDir(CPrime::Variables::CC_CoreApps_ConfigDir()).exists()) {
                status = QDir::home().mkdir(".config/coreapps");
            } else {
                status = true;
            }

            break;
        }

        case CPrime::DriveMountFolder: {
            if (!QDir(CPrime::Variables::CC_CoreApps_MountDir()).exists()) {
                status = QDir::home().mkdir(".config/coreapps/mounts");
            } else {
                status = true;
            }

            break;
        }

        case CPrime::MimeFile: {
            if (!QFile(CPrime::Variables::CC_CoreApps_MimeFilePath()).exists()) {
                MimeUtils *mimeUtils = new MimeUtils;
                mimeUtils->setDefaultsFileName(CPrime::Variables::CC_CoreApps_MimeFilePath());
            }

            status = true;
            break;
        }

        case CPrime::TrashFolder: {
            if (!QDir(CPrime::Variables::CC_Home_TrashDir()).exists()) {
                QDir trash = QDir::home();
                status = trash.cd(".local/share/");
                status = trash.mkdir("Trash");
                status = trash.cd("Trash");
                status = trash.mkdir("files");
                status = trash.mkdir("info");
            } else {
                status = true;
            }

            break;
        }

        case CPrime::RecentActivityFile: {
            QFile file(CPrime::Variables::CC_CoreApps_RecentActFilePath());

            if (file.open(QIODevice::ReadWrite | QIODevice::Text)) {
                status = true;
                file.close();
            } else {
                status = false;
                file.close();
            }
        }
    }

    return status;
}

void CPrime::ValidityFunc::checkTextWidgetPath(QLineEdit *m_t, QObject *parent)
{
    CPrime::FilePathValidate::addForValidation(m_t, parent);
}
